#!/usr/bin/env python3
# PYTHON_ARGCOMPLETE_OK

from cliar import Cliar

from .core import find_versions


class Versions(Cliar):
    """Pip versions.
    List the versions available to a pip package"""

    def list(self, package_name: str, include_pre: bool = False):
        """List the versions available to a package"""
        versions = find_versions(package_name, include_pre)
        for v in sorted(set(versions)):
            print(v)

    def latest(self, package_name: str, include_pre: bool = False):
        """Show the latest version of a package"""
        versions = find_versions(package_name, include_pre)
        print(sorted(versions)[-1])


def entry_point():
    Versions().parse()


if __name__ == "__main__":
    entry_point()



from pip._internal.commands import install
from pip._internal.network.session import PipSession


def find_versions(package_name: str, include_pre: bool = False):
    session = PipSession()
    x = install.InstallCommand("_", "_")
    options = x.parse_args([])[0]
    finder = x._build_package_finder(
        options=options,
        session=session,
        target_python=None,
        ignore_requires_python=False,
    )
    candidates = finder.find_all_candidates(package_name)
    for candidate in candidates:
        if not include_pre and candidate.version.pre:
            continue
        yield candidate.version
